# CertificateRevocationProxy

The Certificate Revocation Proxy allows proxying CRL/OCSP revocation requests. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**local_binds** | [**[AgentConnectorLocalBind]**](AgentConnectorLocalBind.md) | A list describing the local proxy binds for certificate revocation requests.  | 
**trusted_cert_bundle** | **str** | Unique identifier | [optional] 
**rules_bundle** | **str** | Unique identifier | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


